#
# spec file for package qrtool
#
# Copyright (c) 2025 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch s390x
%bcond_with test
%else
%bcond_without test
%endif
Name:           qrtool
Version:        0.12.0
Release:        1.1
Summary:        An utility for encoding or decoding QR code
License:        MIT AND CC-BY-4.0 AND Apache-2.0
Group:          Productivity/Graphics/Visualization/Other
URL:            https://github.com/sorairolake/qrtool
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  rubygem(asciidoctor)

%description
qrtool is a command-line utility for encoding or decoding QR code.

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

%install
install -Dm755 target/release/%{name} -t %{buildroot}%{_bindir}
install -Dm644 target/release/build/qrtool*/out/*.? -t %{buildroot}%{_mandir}/man1

comp="target/release/%{name} completion"
$comp bash >"target/release/%{name}.bash"
$comp fish >"target/release/%{name}.fish"
$comp zsh >"target/release/_%{name}"

install -Dm644 target/release/%{name}.bash -t \
    %{buildroot}%{_datadir}/bash-completion/completions
install -Dm644 target/release/%{name}.fish -t \
    %{buildroot}%{_datadir}/fish/vendor_completions.d
install -Dm644 target/release/_%{name} -t \
    %{buildroot}%{_datadir}/zsh/site-functions

%if %{with test}
%check
%{cargo_test}
%endif

%files
%license LICENSE-*
%doc README* CHANGELOG.adoc
%{_bindir}/%{name}
%{_mandir}/man1/qrtool*
%{_datadir}/bash-completion/completions
%{_datadir}/fish
%{_datadir}/zsh

%changelog
* Thu Jun 12 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.12.0
  * Restore demo animation
  * Change the license for documents and assets to CC BY 4.0
  * Replace --generate-completion with completion subcommand
  * Remove help text for after auto-generated --help
  * Make the message for --version the same as the message for -V
  * Allow partial matches of subcommand names
- Removed cargo_audit from _service due that contains vendor now
* Tue Oct 29 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.11.6
  * Add Supports decoding from XBM
  * Fixed fall-back to decoding an inverted image
* Sun Sep 22 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.11.5
  * Add Supports oklab() and oklch() for --foreground and
  - -background
- Add completion script
* Sun Aug  4 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.11.4
  * Read only the first 7,090 bytes of the input data when encoding
  * Predict input SVG image based on file contents instead of
    filename extension
  * Reduce size of ANSI escaped string
* Fri Jul 12 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.11.2
  * Add support for PIC output format
  * Add ASCII string and ANSI escape sequences to the output
    format
  * Add values for inverting foreground and background colors
    when the output format is a string
  * Rename terminal to unicode, and making terminal an alias for
    unicode
* Wed Jul  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.11.0
  * Change --zopfli to allow it to take a value. If the value is
    not specified, it is assumed that 15 is specified. This is the
    same as before the change
* Sat Jun 29 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.10.13
  * Add options to optimize output PNG image
  * Change the encode command to return an error if --type is
    terminal and the --foreground and/or --background options
    specify values other than the default
* Thu Jun 27 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.10.11
  * Update examples in man pages
  * Allow input image formats other than PNG to be disabled
  * Change to remove unnecessary files from the book
- Enable cargo test except on s390x (failed on decode_from_open_exr
  and decode_from_qoi)
* Mon Dec 25 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
